<?php
/**
 * Plugin Name: Market Scan Graph Widget
 * Plugin URI:
 * Description: A widget that serves as an Market Scan Graph for developing more advanced widgets.
 * Version: 0.1
 * Author: Justin Tadlock
 * Author URI: 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

/**
 * Add function to widgets_init that'll load our widget.
 * @since 0.1
 */
add_action( 'widgets_init', 'market_scan_graph_widgets' );

/**
 * Register our widget.
 * 'market_scan_graph_widgets' is the widget class used below.
 *
 * @since 0.1
 */
function market_scan_graph_widgets() {
	register_widget( 'Market_Scan_Graph' );
}

/**
 * Market Scan Graph Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 * @since 0.1
 */
class Market_Scan_Graph extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function Market_Scan_Graph() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'Market Scan Graph', 'description' => __('An Market Scan Graph widget that displays market graph ', 'Market Scan Graph') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'market-scan-graph-widget' );

		/* Create the widget. */
		$this->WP_Widget( 'market-scan-graph-widget', __('Market Scan Graph Widget', 'Market Scan Graph'), $widget_ops, $control_ops );
	}

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$param1 =  $instance['param1'];
		$param2 =  $instance['param2'];
		$param3 =  $instance['param3'];
		/* Before widget (defined by themes). */
		
			 
		
		if(isset($instance)){
         	echo $before_title; ?>
			
            <form action="<?php echo $_SERVER['REQUEST_URI']; ?>" method="post" >
                 <input type="text" name="symbol" id="symbol" value="Enter Symbol" onfocus="if(this.value=='Enter Symbol')this.value=''" onclick="change_color();" onblur="if(this.value=='')this.value='Enter Symbol'" />	
                 <input type="submit" value="Go" />
             </form>
            
			<?php 
			echo $after_title;
			if(isset($_REQUEST['symbol'])){
				$param1=$_REQUEST['symbol'];
			}
			market_scan_wp_chart($param1,$param2,$param3);
		}
		
		
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['param1'] = strip_tags( $new_instance['param1'] );
		$instance['param2'] = strip_tags( $new_instance['param2'] );
		$instance['param3'] = strip_tags( $new_instance['param3'] );
		
			
		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'param1' => __('goog'), 'param2' => __('300px'), 'param3' => '250px');
		
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'param1' ); ?>"><?php _e('symbol:', 'hybrid'); ?></label>
			<input id="<?php echo $this->get_field_id( 'param1' ); ?>" name="<?php echo $this->get_field_name( 'param1' ); ?>" value="<?php echo $instance['param1']; ?>" style="width:50%;" />
		</p>
        <p>
			<label for="<?php echo $this->get_field_id( 'param2' ); ?>"><?php _e('width:', 'hybrid'); ?></label>&nbsp;&nbsp;&nbsp;&nbsp;
			<input id="<?php echo $this->get_field_id( 'param2' ); ?>" name="<?php echo $this->get_field_name( 'param2' ); ?>" value="<?php echo $instance['param2']; ?>" style="width:50%;" />
		</p>
        <p>
			<label for="<?php echo $this->get_field_id( 'param3' ); ?>"><?php _e('height:', 'hybrid'); ?></label>&nbsp;&nbsp;
			<input id="<?php echo $this->get_field_id( 'param3' ); ?>" name="<?php echo $this->get_field_name( 'param3' ); ?>" value="<?php echo $instance['param3']; ?>" style="width:50%;" />
		</p>


	<?php
	}
}

?>